--- openflow-2013-12-17-2.h	2015-07-23 09:54:17.840479390 -0700
+++ openflow-2013-12-17-3.h	2015-07-23 09:54:17.848479391 -0700
@@ -2246,8 +2246,8 @@
 
     /* Meter configuration.
      * The request body is struct ofp_meter_multipart_request.
-     * The reply body is an array of struct ofp_meter_config. */
-    OFPMP_METER_CONFIG = 10,
+     * The reply body is an array of struct ofp_meter_desc. */
+    OFPMP_METER_DESC = 10,
 
     /* Meter features.
      * The request body is empty.
@@ -2781,7 +2781,7 @@
 };
 OFP_ASSERT(sizeof(struct ofp_group_features) == 40);
 
 /* Body of OFPMP_METER_STATS and OFPMP_METER_CONFIG requests. */
 struct ofp_meter_multipart_request {
     uint32_t meter_id;       /* Meter instance, or OFPM_ALL. */
     uint8_t pad[4];          /* Align to 64 bits. */
@@ -2811,15 +2811,15 @@
 };
 OFP_ASSERT(sizeof(struct ofp_meter_stats) == 40);
 
-/* Body of reply to OFPMP_METER_CONFIG request. Meter configuration. */
-struct ofp_meter_config {
+/* Body of reply to OFPMP_METER_DESC request. Meter configuration. */
+struct ofp_meter_desc {
     uint16_t        length;           /* Length of this entry. */
     uint16_t        flags;            /* All OFPMC_* that apply. */
     uint32_t        meter_id;         /* Meter instance. */
     struct ofp_meter_band_header bands[0]; /* The bands length is
                                          inferred from the length field. */
 };
-OFP_ASSERT(sizeof(struct ofp_meter_config) == 8);
+OFP_ASSERT(sizeof(struct ofp_meter_desc) == 8);
 
 /* Meter feature flags */
 enum ofp_meter_feature_flags {
@@ -2781,7 +2781,7 @@
 OFP_ASSERT(sizeof(struct ofp_group_features) == 40);
 
-/* Body of OFPMP_METER_STATS and OFPMP_METER_CONFIG requests. */
+/* Body of OFPMP_METER_STATS and OFPMP_METER_DESC requests. */
 struct ofp_meter_multipart_request {
     uint32_t meter_id;       /* Meter instance, or OFPM_ALL. */
